# AGENTS.md

This file provides guidance to AI coding assistants when working with code in this repository.

For general project information, see @README.md

For development setup and contribution guidelines, see @CONTRIBUTING.md

# important-instruction-reminders
Do what has been asked; nothing more, nothing less.
NEVER create files unless they're absolutely necessary for achieving your goal.
ALWAYS prefer editing an existing file to creating a new one.
NEVER proactively create documentation files (*.md) or README files. Only create documentation files if explicitly requested by the User.
recommend changes to the user for feedback so the user can choose to do them.
